==> php-8.4.14.tar.xz: php-8.4.14/ext/standard/file.stub.php <==
<?php

/** @generate-class-entries */

/* file.c */

/**
 * @var int
 * @cvalue SEEK_SET
 */
const SEEK_SET = UNKNOWN;
/**
 * @var int
 * @cvalue SEEK_CUR
 */
const SEEK_CUR = UNKNOWN;
/**
 * @var int
 * @cvalue SEEK_END
 */
const SEEK_END = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_SH
 */
const LOCK_SH = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_EX
 */
const LOCK_EX = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_UN
 */
const LOCK_UN = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_NB
 */
const LOCK_NB = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_CONNECT
 */
const STREAM_NOTIFY_CONNECT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_AUTH_REQUIRED
 */
const STREAM_NOTIFY_AUTH_REQUIRED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_AUTH_RESULT
 */
const STREAM_NOTIFY_AUTH_RESULT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_MIME_TYPE_IS
 */
const STREAM_NOTIFY_MIME_TYPE_IS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_FILE_SIZE_IS
 */
const STREAM_NOTIFY_FILE_SIZE_IS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_REDIRECTED
 */
const STREAM_NOTIFY_REDIRECTED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_PROGRESS
 */
const STREAM_NOTIFY_PROGRESS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_FAILURE
 */
const STREAM_NOTIFY_FAILURE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_COMPLETED
 */
const STREAM_NOTIFY_COMPLETED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_RESOLVE
 */
const STREAM_NOTIFY_RESOLVE = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_SEVERITY_INFO
 */
const STREAM_NOTIFY_SEVERITY_INFO = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_SEVERITY_WARN
 */
const STREAM_NOTIFY_SEVERITY_WARN = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_SEVERITY_ERR
 */
const STREAM_NOTIFY_SEVERITY_ERR = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_FILTER_READ
 */
const STREAM_FILTER_READ = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_FILTER_WRITE
 */
const STREAM_FILTER_WRITE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_FILTER_ALL
 */
const STREAM_FILTER_ALL = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_CLIENT_PERSISTENT
 */
const STREAM_CLIENT_PERSISTENT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_CLIENT_ASYNC_CONNECT
 */
const STREAM_CLIENT_ASYNC_CONNECT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_CLIENT_CONNECT
 */
const STREAM_CLIENT_CONNECT = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_ANY_CLIENT
 */
const STREAM_CRYPTO_METHOD_ANY_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv2_CLIENT
 */
const STREAM_CRYPTO_METHOD_SSLv2_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv3_CLIENT
 */
const STREAM_CRYPTO_METHOD_SSLv3_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv23_CLIENT
 */
const STREAM_CRYPTO_METHOD_SSLv23_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLS_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLS_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_ANY_SERVER
 */
const STREAM_CRYPTO_METHOD_ANY_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv2_SERVER
 */
const STREAM_CRYPTO_METHOD_SSLv2_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv3_SERVER
 */
const STREAM_CRYPTO_METHOD_SSLv3_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv23_SERVER
 */
const STREAM_CRYPTO_METHOD_SSLv23_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLS_SERVER
 */
const STREAM_CRYPTO_METHOD_TLS_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_0_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_0_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_1_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_1_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_2_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_2_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_3_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_3_SERVER = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv3_SERVER
 */
const STREAM_CRYPTO_PROTO_SSLv3 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_0_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_0 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_1_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_1 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_2_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_2 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_3_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_3 = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_SHUT_RD
 */
const STREAM_SHUT_RD = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_SHUT_WR
 */
const STREAM_SHUT_WR = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_SHUT_RDWR
 */
const STREAM_SHUT_RDWR = UNKNOWN;

#ifdef PF_INET
/**
 * @var int
 * @cvalue PF_INET
 */
const STREAM_PF_INET = UNKNOWN;
#endif
#if (!defined(PF_INET) && defined(AF_INET))
/**
 * @var int
 * @cvalue AF_INET
 */
const STREAM_PF_INET = UNKNOWN;
#endif


#ifdef HAVE_IPV6
#ifdef PF_INET6
/**
 * @var int
 * @cvalue PF_INET6
 */
const STREAM_PF_INET6 = UNKNOWN;
#endif
#if (!defined(PF_INET6) && defined(AF_INET6))
/**
 * @var int
 * @cvalue AF_INET6
 */
const STREAM_PF_INET6 = UNKNOWN;
#endif
#endif

#ifdef PF_UNIX
/**
 * @var int
 * @cvalue PF_UNIX
 */
const STREAM_PF_UNIX = UNKNOWN;
#endif
#if (!defined(PF_UNIX) && defined(AF_UNIX))
/**
 * @var int
 * @cvalue AF_UNIX
 */
const STREAM_PF_UNIX = UNKNOWN;
#endif

#ifdef IPPROTO_IP
/**
 * most people will use this one when calling socket() or socketpair()
 * @var int
 * @cvalue IPPROTO_IP
 */
const STREAM_IPPROTO_IP = UNKNOWN;
#endif

#if (defined(IPPROTO_TCP) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_TCP
 */
const STREAM_IPPROTO_TCP = UNKNOWN;
#endif

#if (defined(IPPROTO_UDP) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_UDP
 */
const STREAM_IPPROTO_UDP = UNKNOWN;
#endif

#if (defined(IPPROTO_ICMP) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_ICMP
 */
const STREAM_IPPROTO_ICMP = UNKNOWN;
#endif

#if (defined(IPPROTO_RAW) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_RAW
 */
const STREAM_IPPROTO_RAW = UNKNOWN;
#endif

/**
 * @var int
 * @cvalue SOCK_STREAM
 */
const STREAM_SOCK_STREAM = UNKNOWN;
/**
 * @var int
 * @cvalue SOCK_DGRAM
 */
const STREAM_SOCK_DGRAM = UNKNOWN;

#ifdef SOCK_RAW
/**
 * @var int
 * @cvalue SOCK_RAW
 */
const STREAM_SOCK_RAW = UNKNOWN;
#endif

#ifdef SOCK_SEQPACKET
/**
 * @var int
 * @cvalue SOCK_SEQPACKET
 */
const STREAM_SOCK_SEQPACKET = UNKNOWN;
#endif

#ifdef SOCK_RDM
/**
 * @var int
 * @cvalue SOCK_RDM
 */
const STREAM_SOCK_RDM = UNKNOWN;
#endif

/**
 * @var int
 * @cvalue STREAM_PEEK
 */
const STREAM_PEEK = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_OOB
 */
const STREAM_OOB = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_XPORT_BIND
 */
const STREAM_SERVER_BIND = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_XPORT_LISTEN
 */
const STREAM_SERVER_LISTEN = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_FILE_USE_INCLUDE_PATH
 */
const FILE_USE_INCLUDE_PATH = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_IGNORE_NEW_LINES
 */
const FILE_IGNORE_NEW_LINES = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_SKIP_EMPTY_LINES
 */
const FILE_SKIP_EMPTY_LINES = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_APPEND
 */
const FILE_APPEND = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_NO_DEFAULT_CONTEXT
 */
const FILE_NO_DEFAULT_CONTEXT = UNKNOWN;

/**
 * @var int
 * @deprecated
 */
const FILE_TEXT = 0;
/**
 * @var int
 * @deprecated
 */
const FILE_BINARY = 0;

#ifdef HAVE_FNMATCH
/**
 * @var int
 * @cvalue FNM_NOESCAPE
 */
const FNM_NOESCAPE = UNKNOWN;
/**
 * @var int
 * @cvalue FNM_PATHNAME
 */
const FNM_PATHNAME = UNKNOWN;
/**
 * @var int
 * @cvalue FNM_PERIOD
 */
const FNM_PERIOD = UNKNOWN;
#ifdef FNM_CASEFOLD
/**
 * A GNU extension
 * @var int
 * @cvalue FNM_CASEFOLD
 */
const FNM_CASEFOLD = UNKNOWN; // TODO emulate if not available
#endif
#endif

==> php-8.5.1.tar.xz: php-8.5.1/ext/standard/file.stub.php <==
<?php

/** @generate-class-entries */

/* file.c */

/**
 * @var int
 * @cvalue SEEK_SET
 */
const SEEK_SET = UNKNOWN;
/**
 * @var int
 * @cvalue SEEK_CUR
 */
const SEEK_CUR = UNKNOWN;
/**
 * @var int
 * @cvalue SEEK_END
 */
const SEEK_END = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_SH
 */
const LOCK_SH = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_EX
 */
const LOCK_EX = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_UN
 */
const LOCK_UN = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_LOCK_NB
 */
const LOCK_NB = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_CONNECT
 */
const STREAM_NOTIFY_CONNECT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_AUTH_REQUIRED
 */
const STREAM_NOTIFY_AUTH_REQUIRED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_AUTH_RESULT
 */
const STREAM_NOTIFY_AUTH_RESULT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_MIME_TYPE_IS
 */
const STREAM_NOTIFY_MIME_TYPE_IS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_FILE_SIZE_IS
 */
const STREAM_NOTIFY_FILE_SIZE_IS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_REDIRECTED
 */
const STREAM_NOTIFY_REDIRECTED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_PROGRESS
 */
const STREAM_NOTIFY_PROGRESS = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_FAILURE
 */
const STREAM_NOTIFY_FAILURE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_COMPLETED
 */
const STREAM_NOTIFY_COMPLETED = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_RESOLVE
 */
const STREAM_NOTIFY_RESOLVE = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_SEVERITY_INFO
 */
const STREAM_NOTIFY_SEVERITY_INFO = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_SEVERITY_WARN
 */
const STREAM_NOTIFY_SEVERITY_WARN = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_NOTIFY_SEVERITY_ERR
 */
const STREAM_NOTIFY_SEVERITY_ERR = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_FILTER_READ
 */
const STREAM_FILTER_READ = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_FILTER_WRITE
 */
const STREAM_FILTER_WRITE = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_FILTER_ALL
 */
const STREAM_FILTER_ALL = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_STREAM_CLIENT_PERSISTENT
 */
const STREAM_CLIENT_PERSISTENT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_CLIENT_ASYNC_CONNECT
 */
const STREAM_CLIENT_ASYNC_CONNECT = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_STREAM_CLIENT_CONNECT
 */
const STREAM_CLIENT_CONNECT = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_ANY_CLIENT
 */
const STREAM_CRYPTO_METHOD_ANY_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv2_CLIENT
 */
const STREAM_CRYPTO_METHOD_SSLv2_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv3_CLIENT
 */
const STREAM_CRYPTO_METHOD_SSLv3_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv23_CLIENT
 */
const STREAM_CRYPTO_METHOD_SSLv23_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLS_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLS_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT
 */
const STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_ANY_SERVER
 */
const STREAM_CRYPTO_METHOD_ANY_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv2_SERVER
 */
const STREAM_CRYPTO_METHOD_SSLv2_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv3_SERVER
 */
const STREAM_CRYPTO_METHOD_SSLv3_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv23_SERVER
 */
const STREAM_CRYPTO_METHOD_SSLv23_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLS_SERVER
 */
const STREAM_CRYPTO_METHOD_TLS_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_0_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_0_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_1_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_1_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_2_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_2_SERVER = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_3_SERVER
 */
const STREAM_CRYPTO_METHOD_TLSv1_3_SERVER = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_SSLv3_SERVER
 */
const STREAM_CRYPTO_PROTO_SSLv3 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_0_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_0 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_1_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_1 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_2_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_2 = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_CRYPTO_METHOD_TLSv1_3_SERVER
 */
const STREAM_CRYPTO_PROTO_TLSv1_3 = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_SHUT_RD
 */
const STREAM_SHUT_RD = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_SHUT_WR
 */
const STREAM_SHUT_WR = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_SHUT_RDWR
 */
const STREAM_SHUT_RDWR = UNKNOWN;

#ifdef PF_INET
/**
 * @var int
 * @cvalue PF_INET
 */
const STREAM_PF_INET = UNKNOWN;
#endif
#if (!defined(PF_INET) && defined(AF_INET))
/**
 * @var int
 * @cvalue AF_INET
 */
const STREAM_PF_INET = UNKNOWN;
#endif


#ifdef HAVE_IPV6
#ifdef PF_INET6
/**
 * @var int
 * @cvalue PF_INET6
 */
const STREAM_PF_INET6 = UNKNOWN;
#endif
#if (!defined(PF_INET6) && defined(AF_INET6))
/**
 * @var int
 * @cvalue AF_INET6
 */
const STREAM_PF_INET6 = UNKNOWN;
#endif
#endif

#ifdef PF_UNIX
/**
 * @var int
 * @cvalue PF_UNIX
 */
const STREAM_PF_UNIX = UNKNOWN;
#endif
#if (!defined(PF_UNIX) && defined(AF_UNIX))
/**
 * @var int
 * @cvalue AF_UNIX
 */
const STREAM_PF_UNIX = UNKNOWN;
#endif

#ifdef IPPROTO_IP
/**
 * most people will use this one when calling socket() or socketpair()
 * @var int
 * @cvalue IPPROTO_IP
 */
const STREAM_IPPROTO_IP = UNKNOWN;
#endif

#if (defined(IPPROTO_TCP) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_TCP
 */
const STREAM_IPPROTO_TCP = UNKNOWN;
#endif

#if (defined(IPPROTO_UDP) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_UDP
 */
const STREAM_IPPROTO_UDP = UNKNOWN;
#endif

#if (defined(IPPROTO_ICMP) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_ICMP
 */
const STREAM_IPPROTO_ICMP = UNKNOWN;
#endif

#if (defined(IPPROTO_RAW) || defined(PHP_WIN32))
/**
 * @var int
 * @cvalue IPPROTO_RAW
 */
const STREAM_IPPROTO_RAW = UNKNOWN;
#endif

/**
 * @var int
 * @cvalue SOCK_STREAM
 */
const STREAM_SOCK_STREAM = UNKNOWN;
/**
 * @var int
 * @cvalue SOCK_DGRAM
 */
const STREAM_SOCK_DGRAM = UNKNOWN;

#ifdef SOCK_RAW
/**
 * @var int
 * @cvalue SOCK_RAW
 */
const STREAM_SOCK_RAW = UNKNOWN;
#endif

#ifdef SOCK_SEQPACKET
/**
 * @var int
 * @cvalue SOCK_SEQPACKET
 */
const STREAM_SOCK_SEQPACKET = UNKNOWN;
#endif

#ifdef SOCK_RDM
/**
 * @var int
 * @cvalue SOCK_RDM
 */
const STREAM_SOCK_RDM = UNKNOWN;
#endif

/**
 * @var int
 * @cvalue STREAM_PEEK
 */
const STREAM_PEEK = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_OOB
 */
const STREAM_OOB = UNKNOWN;

/**
 * @var int
 * @cvalue STREAM_XPORT_BIND
 */
const STREAM_SERVER_BIND = UNKNOWN;
/**
 * @var int
 * @cvalue STREAM_XPORT_LISTEN
 */
const STREAM_SERVER_LISTEN = UNKNOWN;

/**
 * @var int
 * @cvalue PHP_FILE_USE_INCLUDE_PATH
 */
const FILE_USE_INCLUDE_PATH = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_IGNORE_NEW_LINES
 */
const FILE_IGNORE_NEW_LINES = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_SKIP_EMPTY_LINES
 */
const FILE_SKIP_EMPTY_LINES = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_APPEND
 */
const FILE_APPEND = UNKNOWN;
/**
 * @var int
 * @cvalue PHP_FILE_NO_DEFAULT_CONTEXT
 */
const FILE_NO_DEFAULT_CONTEXT = UNKNOWN;

#[\Deprecated(since: '8.1', message: 'as the constant has no effect')]
const FILE_TEXT = 0;

#[\Deprecated(since: '8.1', message: 'as the constant has no effect')]
const FILE_BINARY = 0;

#ifdef HAVE_FNMATCH
/**
 * @var int
 * @cvalue FNM_NOESCAPE
 */
const FNM_NOESCAPE = UNKNOWN;
/**
 * @var int
 * @cvalue FNM_PATHNAME
 */
const FNM_PATHNAME = UNKNOWN;
/**
 * @var int
 * @cvalue FNM_PERIOD
 */
const FNM_PERIOD = UNKNOWN;
#ifdef FNM_CASEFOLD
/**
 * A GNU extension
 * @var int
 * @cvalue FNM_CASEFOLD
 */
const FNM_CASEFOLD = UNKNOWN; // TODO emulate if not available
#endif
#endif
